@@ -29,17 +29,16 @@ class BackendChooseDialog : public QDialog
 {
   Q_OBJECT
   public:
-    explicit BackendChooseDialog( QWidget* parent);
-    ~BackendChooseDialog() override = default;
+    explicit BackendChooseDialog(QWidget* parent);
+    ~BackendChooseDialog() override;
 
     QString backendName();
 
   protected Q_SLOTS:
     void onAccept();
     void updateContent();
+
   private:
-    static const char* descriptionTemplate;
-    static const char* requirementsTemplate;
     Ui::BackendChooserBase m_ui;
     QString m_backend;
 };
