@@ -70,7 +70,11 @@ Cantor::Backend::Capabilities RBackend::capabilities() const
 
 bool RBackend::requirementsFullfilled(QString* const reason) const
 {
+#ifdef Q_OS_WIN
+    const QString& path = QStandardPaths::findExecutable(QLatin1String("cantor_rserver.exe"));
+#else
     const QString& path = QStandardPaths::findExecutable(QLatin1String("cantor_rserver"));
+#endif
     return Cantor::Backend::checkExecutable(QLatin1String("Cantor RServer"), path, reason);
 }
 
