@@ -56,7 +56,11 @@ void RSession::login()
 
     m_process = new QProcess(this);
     m_process->setProcessChannelMode(QProcess::ForwardedErrorChannel);
+#ifdef Q_OS_WIN
+    m_process->start(QStandardPaths::findExecutable(QLatin1String("cantor_rserver.exe")));
+#else
     m_process->start(QStandardPaths::findExecutable(QLatin1String("cantor_rserver")));
+#endif
 
     m_process->waitForStarted();
     m_process->waitForReadyRead();
